@@ -54,7 +54,7 @@ class BasePowertoolsFormatter(logging.Formatter, metaclass=ABCMeta):
 
 
 class LambdaPowertoolsFormatter(BasePowertoolsFormatter):
-    """AWS Lambda Powertools Logging formatter.
+    """Powertools for AWS Lambda (Python) Logging formatter.
 
     Formats the log message as a JSON encoded string. If the message is a
     dict it will be used directly.
@@ -139,11 +139,11 @@ class LambdaPowertoolsFormatter(BasePowertoolsFormatter):
         if self.utc:
             self.converter = time.gmtime
 
-        super(LambdaPowertoolsFormatter, self).__init__(datefmt=self.datefmt)
-
         self.keys_combined = {**self._build_default_keys(), **kwargs}
         self.log_format.update(**self.keys_combined)
 
+        super().__init__(datefmt=self.datefmt)
+
     def serialize(self, log: Dict) -> str:
         """Serialize structured log dict to JSON str"""
         return self.json_serializer(log)
