@@ -55,6 +55,11 @@ class ActiveMQMessage(DictWrapper):
         """Time stamp (in milliseconds) for when the message left the broker."""
         return self["brokerOutTime"]
 
+    @property
+    def properties(self) -> dict:
+        """Custom properties"""
+        return self["properties"]
+
     @property
     def destination_physicalname(self) -> str:
         return self["destination"]["physicalname"]
