@@ -4,8 +4,6 @@ import zipfile
 from typing import Any, Dict, List, Optional
 from urllib.parse import unquote_plus
 
-import boto3
-
 from aws_lambda_powertools.utilities.data_classes.common import DictWrapper
 
 
@@ -16,14 +14,14 @@ class CodePipelineConfiguration(DictWrapper):
         return self["FunctionName"]
 
     @property
-    def user_parameters(self) -> str:
+    def user_parameters(self) -> Optional[str]:
         """User parameters"""
-        return self["UserParameters"]
+        return self.get("UserParameters", None)
 
     @property
-    def decoded_user_parameters(self) -> Dict[str, Any]:
+    def decoded_user_parameters(self) -> Optional[Dict[str, Any]]:
         """Json Decoded user parameters"""
-        if self._json_data is None:
+        if self._json_data is None and self.user_parameters is not None:
             self._json_data = json.loads(self.user_parameters)
         return self._json_data
 
@@ -80,6 +78,8 @@ class CodePipelineArtifact(DictWrapper):
 
 
 class CodePipelineArtifactCredentials(DictWrapper):
+    _sensitive_properties = ["secret_access_key", "session_token"]
+
     @property
     def access_key_id(self) -> str:
         return self["accessKeyId"]
@@ -97,6 +97,16 @@ class CodePipelineArtifactCredentials(DictWrapper):
         return self.get("expirationTime")
 
 
+class CodePipelineEncryptionKey(DictWrapper):
+    @property
+    def get_id(self) -> str:
+        return self["id"]
+
+    @property
+    def get_type(self) -> str:
+        return self["type"]
+
+
 class CodePipelineData(DictWrapper):
     """CodePipeline Job Data"""
 
@@ -125,6 +135,12 @@ class CodePipelineData(DictWrapper):
         """A continuation token if continuing job"""
         return self.get("continuationToken")
 
+    @property
+    def encryption_key(self) -> Optional[CodePipelineEncryptionKey]:
+        """Represents a CodePipeline encryption key"""
+        key_data = self.get("encryptionKey")
+        return CodePipelineEncryptionKey(key_data) if key_data is not None else None
+
 
 class CodePipelineJobEvent(DictWrapper):
     """AWS CodePipeline Job Event
@@ -155,12 +171,12 @@ class CodePipelineJobEvent(DictWrapper):
         return CodePipelineData(self._job["data"])
 
     @property
-    def user_parameters(self) -> str:
+    def user_parameters(self) -> Optional[str]:
         """Action configuration user parameters"""
         return self.data.action_configuration.configuration.user_parameters
 
     @property
-    def decoded_user_parameters(self) -> Dict[str, Any]:
+    def decoded_user_parameters(self) -> Optional[Dict[str, Any]]:
         """Json Decoded action configuration user parameters"""
         return self.data.action_configuration.configuration.decoded_user_parameters
 
@@ -185,12 +201,20 @@ class CodePipelineJobEvent(DictWrapper):
         BaseClient
             An S3 client with the appropriate credentials
         """
-        return boto3.client(
+        # IMPORTING boto3 within the FUNCTION and not at the top level to get
+        # it only when we explicitly want it for better performance.
+        import boto3
+
+        from aws_lambda_powertools.shared import user_agent
+
+        s3 = boto3.client(
             "s3",
             aws_access_key_id=self.data.artifact_credentials.access_key_id,
             aws_secret_access_key=self.data.artifact_credentials.secret_access_key,
             aws_session_token=self.data.artifact_credentials.session_token,
         )
+        user_agent.register_feature_to_client(client=s3, feature="data_classes")
+        return s3
 
     def find_input_artifact(self, artifact_name: str) -> Optional[CodePipelineArtifact]:
         """Find an input artifact by artifact name
