@@ -1,14 +1,30 @@
 import io
 import logging
-from typing import IO, TYPE_CHECKING, AnyStr, Iterable, List, Optional, cast
+from typing import (
+    IO,
+    TYPE_CHECKING,
+    Any,
+    Iterable,
+    List,
+    Optional,
+    Sequence,
+    TypeVar,
+    Union,
+    cast,
+)
 
 import boto3
 
+from aws_lambda_powertools.shared import user_agent
 from aws_lambda_powertools.utilities.streaming.compat import PowertoolsStreamingBody
 
 if TYPE_CHECKING:
+    from mmap import mmap
+
     from mypy_boto3_s3 import Client
 
+    _CData = TypeVar("_CData")
+
 logger = logging.getLogger(__name__)
 
 
@@ -52,6 +68,7 @@ class _S3SeekableIO(IO[bytes]):
         self._sdk_options = sdk_options
         self._sdk_options["Bucket"] = bucket
         self._sdk_options["Key"] = key
+        self._has_user_agent = False
         if version_id is not None:
             self._sdk_options["VersionId"] = version_id
 
@@ -62,6 +79,9 @@ class _S3SeekableIO(IO[bytes]):
         """
         if self._s3_client is None:
             self._s3_client = boto3.client("s3")
+        if not self._has_user_agent:
+            user_agent.register_feature_to_client(client=self._s3_client, feature="streaming")
+            self._has_user_agent = True
         return self._s3_client
 
     @property
@@ -177,8 +197,11 @@ class _S3SeekableIO(IO[bytes]):
     def truncate(self, size: Optional[int] = 0) -> int:
         raise NotImplementedError("this stream is not writable")
 
-    def write(self, data: AnyStr) -> int:
+    def write(self, data: Union[bytes, Union[bytearray, memoryview, Sequence[Any], "mmap", "_CData"]]) -> int:
         raise NotImplementedError("this stream is not writable")
 
-    def writelines(self, lines: Iterable[AnyStr]) -> None:
+    def writelines(
+        self,
+        data: Iterable[Union[bytes, Union[bytearray, memoryview, Sequence[Any], "mmap", "_CData"]]],
+    ) -> None:
         raise NotImplementedError("this stream is not writable")
